qrInterleave: Function to interleave the Data Code and Error Correction Core
Description
Function to interleave the Data Code and Error Correction Core
Usage
qrInterleave(poly, dataPoly, qrInfo)
Arguments
poly
error correction code word polynomial
dataPoly
input data code word polynomial
qrInfo
dataframe that store all the required info to
generate QRcode. Via qrVersionInfo
Value
Interleaved polynomial readied to fill up the QRcode matrix